==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Recommend_Us/language/lang-hungarian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Klds");
define("_FYOURNAME","A te neved:");
define("_FYOUREMAIL","e-mail cmed:");
define("_FFRIENDNAME","Bartod neve:");
define("_FFRIENDEMAIL","Bartod e-mail cme:");
define("_HELLO","Hell,");
define("_YOURFRIEND","egy bartod");
define("_RECOMMEND","Ajnld ezt az oldalt a bartaidnak!");
define("_INTSITE","Egy rdekes weboldal:");
define("_OURSITE","gy gondolta, hogy az oldalunk,");
define("_INTSENT","rdekes, s ezt veled is tudatni akarta.");
define("_FSITENAME","Az oldal neve:");
define("_FSITEURL","Az oldal cme:");
define("_FREFERENCE","Az oldalunk cmt elkldtk ide:");
define("_THANKSREC","Ksznjk, hogy ajnlottl bennnket!");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Recommend_Us/language/lang-hungarian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Klds");
define("_FYOURNAME","A te neved:");
define("_FYOUREMAIL","e-mail cmed:");
define("_FFRIENDNAME","Bartod neve:");
define("_FFRIENDEMAIL","Bartod e-mail cme:");
define("_HELLO","Hell,");
define("_YOURFRIEND","egy bartod");
define("_RECOMMEND","Ajnld ezt az oldalt a bartaidnak!");
define("_INTSITE","Egy rdekes weboldal:");
define("_OURSITE","gy gondolta, hogy az oldalunk,");
define("_INTSENT","rdekes, s ezt veled is tudatni akarta.");
define("_FSITENAME","Az oldal neve:");
define("_FSITEURL","Az oldal cme:");
define("_FREFERENCE","Az oldalunk cmt elkldtk ide:");
define("_THANKSREC","Ksznjk, hogy ajnlottl bennnket!");

?>
